==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/ResendUserFactor.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResendUserFactor
 */
@JsonPropertyOrder({ ResendUserFactor.JSON_PROPERTY_FACTOR_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "factorType", visible = true, defaultImpl = ResendUserFactor.class)

public class ResendUserFactor implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Type of the Factor
     */
    public enum FactorTypeEnum {
        CALL(String.valueOf("call")),

        EMAIL(String.valueOf("email")),

        SMS(String.valueOf("sms")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        FactorTypeEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static FactorTypeEnum fromValue(String value) {
            for (FactorTypeEnum b : FactorTypeEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_FACTOR_TYPE = "factorType";
    protected FactorTypeEnum factorType;

    public ResendUserFactor() {
    }

    public ResendUserFactor factorType(FactorTypeEnum factorType) {

        this.factorType = factorType;
        return this;
    }

    /**
     * Type of the Factor
     *
     * @return factorType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Type of the Factor")
    @JsonProperty(JSON_PROPERTY_FACTOR_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FactorTypeEnum getFactorType() {
        return factorType;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactorType(FactorTypeEnum factorType) {
        this.factorType = factorType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResendUserFactor resendUserFactor = (ResendUserFactor) o;
        return Objects.equals(this.factorType, resendUserFactor.factorType);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(factorType);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResendUserFactor {\n");
        sb.append("    factorType: ").append(toIndentedString(factorType)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/ResendUserFactor.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResendUserFactor
 */
@JsonPropertyOrder({ ResendUserFactor.JSON_PROPERTY_FACTOR_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "factorType", visible = true, defaultImpl = ResendUserFactor.class)

public class ResendUserFactor implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Type of the Factor
     */
    public enum FactorTypeEnum {
        CALL(String.valueOf("call")),

        EMAIL(String.valueOf("email")),

        SMS(String.valueOf("sms")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        FactorTypeEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static FactorTypeEnum fromValue(String value) {
            for (FactorTypeEnum b : FactorTypeEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_FACTOR_TYPE = "factorType";
    protected FactorTypeEnum factorType;

    public ResendUserFactor() {
    }

    public ResendUserFactor factorType(FactorTypeEnum factorType) {

        this.factorType = factorType;
        return this;
    }

    /**
     * Type of the Factor
     *
     * @return factorType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Type of the Factor")
    @JsonProperty(JSON_PROPERTY_FACTOR_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FactorTypeEnum getFactorType() {
        return factorType;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactorType(FactorTypeEnum factorType) {
        this.factorType = factorType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResendUserFactor resendUserFactor = (ResendUserFactor) o;
        return Objects.equals(this.factorType, resendUserFactor.factorType);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(factorType);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResendUserFactor {\n");
        sb.append("    factorType: ").append(toIndentedString(factorType)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
